==> infima_client-0.59.0-py3-none-any.whl: infima_client/models/pool_service_get_geolocations_response_200_geos_item.py <==
from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.pool_service_get_geolocations_response_200_geos_item_states_item import (
    PoolService_GetGeolocationsResponse_200GeosItemStatesItem,
)
from ..types import UNSET, Unset

T = TypeVar("T", bound="PoolService_GetGeolocationsResponse_200GeosItem")


@attr.s(auto_attribs=True)
class PoolService_GetGeolocationsResponse_200GeosItem:
    """ Pool State Geographical Distribution. """

    cusip: Union[Unset, str] = UNSET
    states: Union[
        Unset, List[PoolService_GetGeolocationsResponse_200GeosItemStatesItem]
    ] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        cusip = self.cusip
        states: Union[Unset, List[Any]] = UNSET
        if not isinstance(self.states, Unset):
            states = []
            for states_item_data in self.states:
                states_item = states_item_data.to_dict()

                states.append(states_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if cusip is not UNSET:
            field_dict["CUSIP"] = cusip
        if states is not UNSET:
            field_dict["states"] = states

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        cusip = d.pop("CUSIP", UNSET)

        states = []
        _states = d.pop("states", UNSET)
        for states_item_data in _states or []:
            states_item = (
                PoolService_GetGeolocationsResponse_200GeosItemStatesItem.from_dict(
                    states_item_data
                )
            )

            states.append(states_item)

        pool_service_get_geolocations_response_200_geos_item = cls(
            cusip=cusip,
            states=states,
        )

        pool_service_get_geolocations_response_200_geos_item.additional_properties = d
        return pool_service_get_geolocations_response_200_geos_item

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> infima_client-0.186.0-py3-none-any.whl: infima_client/models/pool_service_get_geolocations_response_200_geos_item.py <==
from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.pool_service_get_geolocations_response_200_geos_item_states_item import (
    PoolService_GetGeolocationsResponse_200GeosItemStatesItem,
)
from ..types import UNSET, Unset

T = TypeVar("T", bound="PoolService_GetGeolocationsResponse_200GeosItem")


@attr.s(auto_attribs=True)
class PoolService_GetGeolocationsResponse_200GeosItem:
    """ Pool State Geographical Distribution. """

    cusip: Union[Unset, str] = UNSET
    states: Union[
        Unset, List[PoolService_GetGeolocationsResponse_200GeosItemStatesItem]
    ] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        cusip = self.cusip
        states: Union[Unset, List[Any]] = UNSET
        if not isinstance(self.states, Unset):
            states = []
            for states_item_data in self.states:
                states_item = states_item_data.to_dict()

                states.append(states_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if cusip is not UNSET:
            field_dict["cusip"] = cusip
        if states is not UNSET:
            field_dict["states"] = states

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        cusip = d.pop("cusip", UNSET)

        states = []
        _states = d.pop("states", UNSET)
        for states_item_data in _states or []:
            states_item = (
                PoolService_GetGeolocationsResponse_200GeosItemStatesItem.from_dict(
                    states_item_data
                )
            )

            states.append(states_item)

        pool_service_get_geolocations_response_200_geos_item = cls(
            cusip=cusip,
            states=states,
        )

        pool_service_get_geolocations_response_200_geos_item.additional_properties = d
        return pool_service_get_geolocations_response_200_geos_item

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
